@@ -71,7 +71,7 @@ $ python setup.py help
  * published.  Unfortunately I know of no good way to do this
  * other than with OS-specific tests.
  */
-#if defined(__FreeBSD__) || defined(__linux__) || defined(__sun__)
+#if defined(__FreeBSD__) || defined(__linux__) || defined(__sun__) || defined(__GLIBC__) || (defined(__APPLE__) && defined(__MACH__))
 #define HAVE_IPV6_RFC2553
 #include <arpa/inet.h>
 #endif
@@ -134,8 +134,10 @@ static struct MilterCallback {
 
 #if PY_MAJOR_VERSION >= 3
         static struct smfiDesc description; /* forward declaration */
+        static PyTypeObject milter_ContextType;
 #else
         staticforward struct smfiDesc description; /* forward declaration */
+        staticforward PyTypeObject milter_ContextType;
 #endif
 
 static PyObject *MilterError;
@@ -148,12 +150,6 @@ typedef struct {
 
 static milter_Diag diag;
 
-#if PY_MAJOR_VERSION >= 3
-        static PyTypeObject milter_ContextType;
-#else
-        staticforward PyTypeObject milter_ContextType;
-#endif
-
 typedef struct {
   PyObject_HEAD
   SMFICTX *ctx;		/* libmilter thread state */
@@ -383,7 +379,7 @@ Sets the Python function invoked for each body chunk. There may\n\
 be multiple body chunks passed to the filter. End-of-lines are\n\
 represented as received from SMTP (normally Carriage-Return/Line-Feed).\n\
 Function takes args (ctx, chunk) -> int\n\
-chunk -> String - body data";
+chunk -> bytes - body data";
 
 static PyObject *
 milter_set_body_callback(PyObject *self, PyObject *args) {
@@ -772,13 +768,6 @@ milter_wrap_negotiate(SMFICTX *ctx,
   rc = _generic_wrapper(c, negotiate_callback, arglist);
   c->t = t;
   if (rc == SMFIS_CONTINUE) {
-#if 0	// PyArgs_Parse deprecated and going away
-    if (!PyArgs_Parse(optlist,"[kkkk]",pf0,pf1,pf2,pf3)) {
-      PyErr_Print();
-      PyErr_Clear();	/* must clear since not returning to python */
-      rc = SMFIS_REJECT;
-    }
-#else
     unsigned long *pa[4] = { pf0,pf1,pf2,pf3 };
     unsigned long fa[4] = { f0,f1,f2,f3 };
     int len = PyList_Size(optlist);
@@ -797,7 +786,6 @@ milter_wrap_negotiate(SMFICTX *ctx,
       PyErr_Clear();
       rc = SMFIS_REJECT;
     }
-#endif
   }
   else if (rc != SMFIS_ALL_OPTS)
     rc = SMFIS_REJECT;
@@ -1157,7 +1145,7 @@ Change/delete a header in the message. \n\
 It is not checked for standards compliance; the mail filter\n\
 must ensure that no protocols are violated as a result of adding this header.\n\
 field - header field name\n\
-int - the Nth occurence of this header\n\
+int - the Nth occurrence of this header\n\
 value - header field value\n\
 field and value are strings.\n\
 This function can only be called from the EOM callback.";
